***************
Developer Guide
***************

If you would like access the the development version of ``nengo_gui``,
you can download it from GitHub.

.. code:: shell

   git clone https://github.com/nengo/nengo-gui.git
   cd nengo-gui
   python setup.py develop --user

The following sections will help you understand how to contribute to Nengo GUI
development.

.. toctree::
   :maxdepth: 2
   codeflow
   workflow
